Mixed-Up Code Questions
------------------------

.. selectquestion:: mixedupcode_network_1_sq
   :fromid: mixedupcode_network_1, mixedupcode_network_1_ac
   :toggle:

.. selectquestion:: mixedupcode_network_2_sq
   :fromid: mixedupcode_network_2, mixedupcode_network_2_ac
   :toggle:

.. selectquestion:: mixedupcode_network_3_sq
   :fromid: mixedupcode_network_3, mixedupcode_network_3_ac
   :toggle:

.. selectquestion:: mixedupcode_network_4_sq
   :fromid: mixedupcode_network_4, mixedupcode_network_4_ac
   :toggle:

.. selectquestion:: mixedupcode_network_5_sq
   :fromid: mixedupcode_network_5, mixedupcode_network_5_ac
   :toggle:

.. selectquestion:: mixedupcode_network_6_sq
   :fromid: mixedupcode_network_6, mixedupcode_network_6_ac
   :toggle:

.. selectquestion:: mixedupcode_network_7_sq
   :fromid: mixedupcode_network_7, mixedupcode_network_7_ac
   :toggle:

.. selectquestion:: mixedupcode_network_8_sq
   :fromid: mixedupcode_network_8, mixedupcode_network_8_ac
   :toggle:

.. selectquestion:: mixedupcode_network_9_sq
   :fromid: mixedupcode_network_9, mixedupcode_network_9_ac
   :toggle:

.. selectquestion:: mixedupcode_network_10_sq
   :fromid: mixedupcode_network_10, mixedupcode_network_10_ac
   :toggle:
